im

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 9, 2026 License: AGPL-3.0 Imports: 5 Imported by: 2

Documentation

Overview

Package im contains image magick commands.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Convert

func Convert(in, out string) error

Convert converts an image from one format to another, based on file extension.

func ConvertToGIF

func ConvertToGIF(folder, outFileName string, fps int)

ConvertToGIF converts a folder of pngs into an animated gif using imagemagick convert.

func MakeMontage

func MakeMontage(cols int, folder, outFileName string)

MakeMontage creates a montage with imagemagick. Set cols to 0 for auto sizing

func Resize

func Resize(path string, width, height int) error

Resize resizes and saves the image.

func ResizeTo

func ResizeTo(in, out string, width, height int) error

ResizeTo resizes the specified image, saving as a new image.

Types

This section is empty.

Jump to