package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Mar 9, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
Package im contains image magick commands.
-
func Convert(in, out string) error
-
func ConvertToGIF(folder, outFileName string, fps int)
-
func MakeMontage(cols int, folder, outFileName string)
-
func Resize(path string, width, height int) error
-
func ResizeTo(in, out string, width, height int) error
Convert converts an image from one format to another, based on file extension.
func ConvertToGIF(folder, outFileName string, fps int)
ConvertToGIF converts a folder of pngs into an animated gif using imagemagick convert.
func MakeMontage(cols int, folder, outFileName string)
MakeMontage creates a montage with imagemagick.
Set cols to 0 for auto sizing
Resize resizes and saves the image.
ResizeTo resizes the specified image, saving as a new image.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.